audb
====

.. automodule:: audb

.. rubric:: Classes

.. autosummary::
    :toctree:
    :nosignatures:

    config
    DatabaseIterator
    Dependencies
    Flavor
    Repository
    
.. rubric:: Functions

.. autosummary::
    :toctree:
    :nosignatures:

    available
    cached
    default_cache_root
    dependencies
    exists
    flavor_path
    latest_version
    load
    load_attachment
    load_media
    load_table
    load_to
    publish
    remove_media
    repository
    stream
    versions
